
var	UNUSUAL_SITUATION = 0;
// UNUSUAL_SITUATION is true if we are participating in challenge of some sort;
// this is detected at eventStartLevel and does some tweaks to the AI to make it
// behave more campaign-like during challenges

var	HIGH_TECH_START = 0;
// Defined at start of the game, this value remembers if we have started at T2
// or at least at T1/advbases

var	MAX_WARRIORS = 150;		// the maximum number of droids in a group
var	NUM_WARRIORS = 24;		// the number of battle droids to maintain in a single group
var	MIN_WARRIORS = 16;		// the number of battle droids necessary to engage in combat
var	MIN_VTOLS = 16;		// the minimum number of vtols to have in attack group before attack
var	NUM_VTOLS = 24;		// thenumber of vtols to maintain in an attack group
var	MAX_VTOLS = 32;		// the maximum size of a vtol attack group
var	NUM_HARASS = 32;		// the number of units to maintain in the harass group
if (difficulty == EASY) {
	MIN_WARRIORS = 5;
	NUM_WARRIORS = 8;
	MIN_VTOLS = 5;
	NUM_VTOLS = 8;
}
else if (difficulty == MEDIUM) {
	MIN_WARRIORS = 10;
	NUM_WARRIORS = 20;
	MIN_VTOLS = 10;
	NUM_VTOLS = 20;
}
else {
	MIN_WARRIORS = 16;
	NUM_WARRIORS = 24;
	MIN_VTOLS = 16;
	NUM_VTOLS = 24;
}

var	NUM_VTOL_GROUPS = MIN_VTOL_GROUPS;
var	ABS_MAX_TRUCKS = 10;			// try not to make too many trucks

var	RATE_AP = 1;		// these values affect the amount of a certain weapon class in the mix
var	RATE_AT = 1;		// this is for anti-tank
var	RATE_AA = 0;		// how much more AA do we need
var	RATE_AB = 0;		// this is for anti-building

var	BUILD_TANKS = 1;		//Useful for controlling whether or not to produce tanks, borgs, or vtols at certain points.
var	BUILD_BORGS = 1;		//Only used by hard AIs.
var	BUILD_VTOLS = 1;

var	RATE_TANK = 1; // these values affect the amount of hover tanks in the mix
var	RATE_HOVER = 0;

var	PEACEFULNESS = .9; //This influences the AI's likelihood of launching "All-In" assaults on enemy bases. A smaller value indicates a more aggressive (reckless?) AI.
var	BECOMES_HARDER = 0; //Controls whether or not to change group sizes during the match.
var	REGROUP_FREQUENCY = 5000; //Controls how often the AI regroups its attack forces.
if (difficulty == EASY) {
	PEACEFULNESS = 1.5; //For an easy AI, we'll want it to turtle some
	REGROUP_FREQUENCY = 0; //...and not regroup at all.
}
else if (difficulty == MEDIUM) {
	PEACEFULNESS = .75; //For a medium AI, we'll want it to be somewhat reckless
	REGROUP_FREQUENCY = 15000; //...and regroup less frequently.
}
else {
	PEACEFULNESS = .9;
	REGROUP_FREQUENCY = 5000;
}

if (difficulty != EASY)
	buildOrder = [factory,lab,lab,command,factory,generator,generator,lab];

//override globals to make use of Contingency material

sensors = [ //Don't bother building any flimsy steel sensor towers. Instead, wait until hardened sensor towers become available.
	"Sys-SensoTowerWS", // wide spectrum sensor
	"Sys-SensoTower02", // hardened sensor
];

cbtower = [
	"Sys-SensoTowerWS", // wide spectrum sensor
	"Sys-CB-Tower02", // Hardened Counter-Battery Tower
];

detector = [
	"Sys-RadarDetector02", // Hardened Radar Detector Tower
];

repair = [
	"A0RepairCentre4", // repair facility 4
	"A0RepairCentre3", // repair facility 3
	"A0RepairCentre2", // repair facility 2
	"A0RepairCentre", // repair facility 1
];

sensorTurrets = [
	"Sensor-WideSpec", // wide spectrum sensor
	"SensorTower2Mk1", // heavy sensor
	"SensorTurret1Mk1", // sensor
];

cbTurrets = [
	"Sys-CBTower01", // heavy cb turret
	"Sys-CBTurret01", // counter-battery turret
];

detectorTurrets = [
	"RadarDetectorHvy", // heavy radar detector
	"RadarDetector", // radar detector
];

truckTurrets = [
	"Spade4Mk1", // truck turret 4
	"Spade3Mk1", // truck turret 3
	"Spade2Mk1", // truck turret 2
	"Spade1Mk1", // truck turret 1
];
truckTurretsLight = [
	"Spade4Mk1", // truck turret 4
	"Spade3Mk1", // truck turret 3
	"Spade2Mk1", // truck turret 2
	"Spade1Mk1", // truck turret 1
];
truckTurretsMedium = truckTurretsLight;
truckTurretsHeavy = [
	"Spade4Hvy", // truck turret 4
	"Spade3Hvy", // truck turret 3
	"Spade2Hvy", // truck turret 2
	"Spade1Hvy", // truck turret 1
];
truckTurretsHeavy = truckTurretsHeavy.concat(truckTurretsLight);

truckBodies = contingencyBodiesLightCheap;
truckBodiesLight = contingencyBodiesLightArmored;
truckBodiesMedium = contingencyBodiesMediumArmored;
truckBodiesHeavy = contingencyBodiesHeavyArmored;
truckBodiesLightHover = contingencyBodiesLightCheap;
//truckBodiesMediumHover = contingencyBodiesMediumCheap;
//truckBodiesHeavyHover = contingencyBodiesHeavyCheap;

truckPropulsionsLight = [
	"tracked01", // tracks
	"HalfTrack", // half-track
	"wheeled01", // wheels
];
truckPropulsionsMedium = truckPropulsionsLight;
truckPropulsionsHeavy = truckPropulsionsMedium;

engineerStats = [
	["Cyb-Bod-ComEng4","CyborgSpade4","CyborgLegs"],
	["Cyb-Bod-ComEng3","CyborgSpade3","CyborgLegs"],
	["Cyb-Bod-ComEng2","CyborgSpade2","CyborgLegs"],
	["Cyb-Bod-ComEng","CyborgSpade","CyborgLegs"],
];

	/********************************/
	/* Generic branch specific code */
	/********************************/

function constructPersonality() {

	this.MIN_BUILDERS = 4;		// the usual number of trucks that construct base structures
	this.MAX_BUILDERS = 4;		// the maximum number of trucks that construct base structures
	this.MIN_OILERS = 2;		// the usual number of trucks used for oil hunting
	this.MAX_OILERS = 4;		// the maximum number of trucks used for oil hunting
	this.MIN_DEFENDERS = 4;		// the minimum number of tanks before producing more trucks than necessary
	if (difficulty = EASY)
		this.DEFENSIVENESS = 4;	// regulates chance of spending money on defensive structures. For an easy AI, we'll want it to turtle some.
	else if (difficulty = MEDIUM)
		this.DEFENSIVENESS = 1;
	else
		this.DEFENSIVENESS = .5;
	this.PEACE_TIME = 2.5;		// the amount of minutes for free scouting (regrouping disabled, no defenses built)

	this.THIS_AI_MAKES_TANKS = true;
	this.THIS_AI_MAKES_CYBORGS = true;
	this.THIS_AI_MAKES_VTOLS = true;

	if (typeof(forcePersonality)=="undefined")
		this.subpersonality = random(3);
	else
		this.subpersonality = forcePersonality;

	this.researchPathFundamental = [
		"R-Vehicle-Prop-Halftracks",
		"R-Vehicle-Body04",
		"R-Struc-RepairFacility",
		"R-Struc-PowerModuleMk1",
		"R-Struc-Research-Module",
		"R-Struc-Factory-Cyborg",
		"R-Struc-WindFarm",
		"R-Struc-Factory-Module",
		"R-Struc-Power-Upgrade03",
		"R-Vehicle-Body05",
		"R-Vehicle-Prop-Tracks",
		"R-Vehicle-Body11",
		"R-Sys-Sensor-Tower02",
		"R-Sys-RadarDetectorTower2",
		"R-Sys-CBSensor-Tower02",
		"R-Struc-VTOLPad",
		"R-Struc-VTOLFactory",
		"R-Vehicle-Body23",
		"R-Struc-Power-Upgrade06",
		"R-Vehicle-Armor-Kinetic03",
		"R-Vehicle-Armor-Heat03",
		"R-Sys-Autorepair-General",
		"R-Vehicle-Body09",
		"R-Vehicle-Engine02",
		"R-Sys-Spade2Mk1",
		"R-Struc-RepairFacility2",
		"R-Sys-Resistance-Upgrade01",
		"R-Vehicle-Body25",
		"R-Struc-Power-Upgrade09",
		"R-Vehicle-Armor-Kinetic06",
		"R-Vehicle-Armor-Heat06",
		"R-Sys-Autorepair-Upgrade01",
		"R-Vehicle-Body22",
		"R-Vehicle-Engine03",
		"R-Sys-Spade3Mk1",
		"R-Struc-RepairFacility3",
		"R-Sys-Resistance-Upgrade02",
		"R-Vehicle-Body27",
		"R-Wpn-LasSat",
		"R-Sys-Sensor-WSTower",
		"R-Sys-Sensor-UpLink",
		"R-Vehicle-Armor-Kinetic09",
		"R-Vehicle-Armor-Heat09",
		"R-Sys-Autorepair-Upgrade02",
		"R-Vehicle-Body13",
		"R-Vehicle-Engine05",
		"R-Sys-Spade4Mk1",
		"R-Struc-RepairFacility4",
		"R-Sys-Resistance-Upgrade03",
	];
	
	this.researchPathEconomy = [
		"R-Struc-PowerModuleMk1",
		"R-Struc-WindFarm",
		"R-Struc-Power-Upgrade03",
		"R-Struc-Power-Upgrade06",
		"R-Struc-Power-Upgrade09",
	];
	
	this.abWeapons = [
	[
		"HowitzerGaussRot",
		"HowitzerGaussHvy",
		"HowitzerGauss",
		"Mortar-GaussRot",
		"Mortar-GaussHvy",
		"Mortar-Gauss",
		"Howitzer-Incenediary",
		"Mortar-Incenediary",
		"Howitzer03-Rot",
		"Howitzer150Mk1",
		"Howitzer105Mk1",
		"Mortar3ROTARYMk1",
		"Mortar2Mk1",
		"Mortar1Mk1",
	],
	[
		"HowitzerGaussRot",
		"HowitzerGaussHvy",
		"HowitzerGauss",
		"Howitzer-Incenediary",
		"Howitzer03-Rot",
		"Howitzer150Mk1",
		"Howitzer105Mk1",
		"Mortar-GaussRot",
		"Mortar-GaussHvy",
		"Mortar-Gauss",
		"Mortar-Incenediary",
		"Mortar3ROTARYMk1",
		"Mortar2Mk1",
		"Mortar1Mk1",
	],
	];

	this.abCyborgStats = [
	[
		["HvyCyb-Bod-MortarRot","HvyCyb-Wpn-MortarRot","HvyCyborgLegs"],
		["Cyb-Bod-Grenade","Cyb-Wpn-Grenade","CyborgLegs"],
	],
	];

	this.harassBodies = [contingencyBodiesSuperArmored,];
	this.harassBodies[0] = this.harassBodies[0].concat(contingencyBodiesHeavyArmored,contingencyBodiesMediumArmored,contingencyBodiesLightArmored);
	this.harassPropulsions = [
	[
		"hover01",
		"wheeled01",
	],
	];
	this.harassWeapons = [
	[
		"SpyTurretNEXUS",
		"SpyTurret03",
		"SpyTurret02",
		"SpyTurret01",
	],
	];
	
	switch (this.subpersonality) {
	case 0:

		this.tankBodies = [ contingencyBodiesLightCheap, ];
		this.tankBodiesAP = [ contingencyBodiesHeavy, ];

		this.tankPropulsions = [
		[
			"tracked01", // tracks
			"HalfTrack", // half-track
			"wheeled01", // wheels
		],
		];

		this.apWeapons = [
		[
			"Laser-AP4",
			"Laser-AP3",
			"MG4IncTwin",
			"MG4Inc",
			"MG3IncTwin",
			"MG3Inc",
			"Laser-AP2",
			"MG5TWINROTARY",
			"MG4ROTARYMk1",
			"Laser-AP1",
			"MG3Twin",
			"MG3Mk1",
			"MG2Mk1",
			"MG1Mk1",
		],
		];

		this.atWeapons = [
		[
			"Laser-AT4",
			"Laser-AT3",
			"Laser-AT2",
			"MG-AntiTank2",
			"Laser-AT1",
			"MG-AntiTank",
			"Cannon1Mk1",
		],
		[
			"Laser-TankDest2",
			"Laser-TankDest",
			"MG4IncTwin",
			"MG4Inc",
			"MG3IncTwin",
			"MG3Inc",
		],
		];

		this.abWeapons = this.abWeapons.concat([
		[
			"Laser-Sonic-TankDest",
			"Laser-Sonic",
		],
		]);

		this.aaWeapons = [
		[
			"Laser-AA2",
			"Laser-AA",
			"MG-AA2",
			"MG-AA",
		],
		];

		this.apCyborgStats = [
		[
			["Cyb-Bod-Laser-AP3","Cyb-Wpn-Laser-AP3","CyborgLegs"],
			["Cyb-Bod-MG4Inc","Cyb-Wpn-MG4Inc","CyborgLegs"],
			["Cyb-Bod-Laser-AP1","Cyb-Wpn-Laser-AP1","CyborgLegs"],
			["Cyb-Bod-MG3Inc","Cyb-Wpn-MG3Inc","CyborgLegs"],
			["CybRotMgGrd","CyborgRotMG","CyborgLegs"],
			["CyborgChain1Ground","CyborgChaingun","CyborgLegs"],
		],
		[
			["HvyCyb-Bod-Laser-AP3","HvyCyb-Wpn-Laser-AP3","HvyCyborgLegs"],
			["HvyCyb-Bod-MG4Inc","HvyCyb-Wpn-MG4Inc","HvyCyborgLegs"],
			["HvyCyb-Bod-MG3Inc","HvyCyb-Wpn-MG3Inc","HvyCyborgLegs"],
			["HvyCyb-Bod-Laser-AP1","HvyCyb-Wpn-Laser-AP1","HvyCyborgLegs"],
			["HvyCyb-Bod-MG4","HvyCyb-Wpn-MG4","HvyCyborgLegs"],
			["HvyCyb-Bod-MG3","HvyCyb-Wpn-MG3","HvyCyborgLegs"],
		],
		];

		this.atCyborgStats = [
		[
			["HvyCyb-Bod-Laser-AT3","HvyCyb-Wpn-Laser-AT3","HvyCyborgLegs"],
			["HvyCyb-Bod-MG-AntiTank2","HvyCyb-Wpn-MG-AntiTank2","HvyCyborgLegs"],
			["HvyCyb-Bod-Laser-AT1","HvyCyb-Wpn-Laser-AT1","HvyCyborgLegs"],
			["HvyCyb-Bod-MG-AntiTank","HvyCyb-Wpn-MG-AntiTank","HvyCyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		[
			["Cyb-Bod-Laser-AT3","Cyb-Wpn-Laser-AT3","CyborgLegs"],
			["Cyb-Bod-Laser-AT1","Cyb-Wpn-Laser-AT1","CyborgLegs"],
			["HvyCyb-Bod-MG-AntiTank2","HvyCyb-Wpn-MG-AntiTank2","HvyCyborgLegs"],
			["HvyCyb-Bod-MG-AntiTank","HvyCyb-Wpn-MG-AntiTank","HvyCyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		];

		this.aaCyborgStats = [
		[
			["Cyb-Bod-Laser-AP3","Cyb-Wpn-Laser-AP3","CyborgLegs"],
			["Cyb-Bod-MG4Inc","Cyb-Wpn-MG4Inc","CyborgLegs"],
			["Cyb-Bod-Laser-AP1","Cyb-Wpn-Laser-AP1","CyborgLegs"],
			["Cyb-Bod-MG3Inc","Cyb-Wpn-MG3Inc","CyborgLegs"],
			["CybRotMgGrd","CyborgRotMG","CyborgLegs"],
			["CyborgChain1Ground","CyborgChaingun","CyborgLegs"],
		],
		[
			["HvyCyb-Bod-Laser-AP3","HvyCyb-Wpn-Laser-AP3","HvyCyborgLegs"],
			["HvyCyb-Bod-MG4Inc","HvyCyb-Wpn-MG4Inc","HvyCyborgLegs"],
			["HvyCyb-Bod-MG3Inc","HvyCyb-Wpn-MG3Inc","HvyCyborgLegs"],
			["HvyCyb-Bod-Laser-AP1","HvyCyb-Wpn-Laser-AP1","HvyCyborgLegs"],
			["HvyCyb-Bod-MG4","HvyCyb-Wpn-MG4","HvyCyborgLegs"],
			["HvyCyb-Bod-MG3","HvyCyb-Wpn-MG3","HvyCyborgLegs"],
		],
		];

		this.vtolBodies = [contingencyBodiesVtol,];

		this.vtolWeapons = [
		[
			"Bomb-Earthquake",
			"Bomb-FuelAir",
			"Bomb5-VTOL-Plasmite",
			"Bomb4-VTOL-HvyINC",
			"Bomb2-VTOL-HvHE",
			"Bomb3-VTOL-LtINC",
			"MG-AntiTank2-VTOL",
			"MG-AntiTank-VTOL",
			"Bomb1-VTOL-LtHE",
			"MG4Inc-VTOL",
			"MG3Inc-VTOL",
		],
		];

		this.defenses = [
		[
			"Tower3-Laser-AP3",
			"Tower2-Laser-AP1",
			"Tower3-MG4Inc",
			"Tower-MG3Inc",
			"Tower-RotMg",
			"GuardTower3",
			"GuardTower2",
			"GuardTower1",
		],
		[
			"Bunker3-Laser-AP4",
			"Bunker3-Laser-AP3",
			"Bunker2-Laser-AP2",
			"Bunker2-Laser-AP1",
			"Bunker3-MG4IncTwin",
			"Bunker3-MG4Inc",
			"Bunker-MG3IncTwin",
			"Bunker-MG3Inc",
			"Bunker2-MG5",
			"Pillbox-RotMG",
			"Bunker-MG3Twin",
			"PillBox1",
		],
		[
			"Bunker3-Laser-AT4",
			"Bunker3-Laser-AT3",
			"Bunker2-Laser-AT2",
			"Bunker2-Laser-AT1",
			"Bunker2-MG-AntiTank2",
			"Bunker-MG-AntiTank",
		],
		[
			"Tower3-Laser-AT3",
			"Tower2-Laser-AT1",
			"Tower2-MG-AntiTank2",
			"Tower-MG-AntiTank",
		],
		[
			"Super-Laser2-Fort",
			"Super-Laser-Fort",
			"Super-MGPlas-Fort",
			"Super-MG-Fort",
		],
		];

		this.artillery = [
		[
			"Super-MortarGauss-Empl",
			"Super-Mortar-Empl",
			"Bunker2-Howitzer",
			"Bunker-Mortar",
		],
		[
			"Super-HowitzerGauss-Empl",
			"Super-Howitzer-Empl",
			"Emplacement-Howitzer105",
			"Emplacement-MortarPit01",
		],
		];


		this.antiair = [
		[
			"Bunker3-Laser-AA2",
			"Bunker-Laser-AA",
			"Bunker2-MG-AA2",
			"Bunker-MG-AA",
		],
		];

		this.hardpoints = [
		[
			"WallTower3-Laser-AP4",
			"WallTower3-Laser-AP3",
			"WallTower2-Laser-AP2",
			"WallTower2-Laser-AP1",
			"WallTower3-MG4IncTwin",
			"WallTower3-MG4Inc",
			"WallTower-MG3IncTwin",
			"WallTower-MG3Inc",
			"WallTower-TwinAssaultGun",
			"Wall-RotMg",
			"WallTower-MG3Twin",
			"WallTower01",
		],
		[
			"WallTower3-Laser-AT4",
			"WallTower3-Laser-AT3",
			"WallTower2-Laser-AT2",
			"WallTower2-Laser-AT1",
			"WallTower2-MG-AntiTank2",
			"WallTower-MG-AntiTank",
			"WallTower3-MG4IncTwin",
			"WallTower3-MG4Inc",
			"WallTower-MG3IncTwin",
			"WallTower-MG3Inc",
		],
		];
		
		this.researchPathPrimary = [
			"R-Wpn-Cannon-Damage01",
			"R-Vehicle-Prop-Halftracks",
			"R-Wpn-MG2Mk1",
			"R-Struc-PowerModuleMk1",
			"R-Struc-Factory-Cyborg",
			"R-Vehicle-Body04",
		];

		this.researchPathAT = [
			"R-Defense-Bunker-MG-AntiTank",
			"R-Defense-Tower-MG-AntiTank",
			"R-Defense-WallTower-MG-AntiTank",
			"R-Defense-Bunker2-MG-AntiTank2",
			"R-Defense-Tower2-MG-AntiTank2",
			"R-Defense-WallTower2-MG-AntiTank2",
			"R-Defense-Super-Machinegun",
			"R-Defense-Bunker2-Laser-AT1",
			"R-Defense-Tower2-Laser-AT1",
			"R-Defense-WallTower2-Laser-AT1",
			"R-Defense-Bunker2-Laser-AT2",
			"R-Defense-WallTower2-Laser-AT2",
			"R-Defense-Bunker3-Laser-AT3",
			"R-Defense-Tower3-Laser-AT3",
			"R-Defense-WallTower3-Laser-AT3",
			"R-Defense-Bunker3-Laser-AT4",
			"R-Defense-WallTower3-Laser-AT4",
			"R-Defense-Super-Laser",
		];
		
		this.researchPathAP = [
			"R-Defense-Tower-MG1",
			"R-Defense-Bunker-MG1",
			"R-Defense-Tower-MG2",
			"R-Defense-Bunker-MG2",
			"R-Defense-Tower-MG3",
			"R-Defense-Bunker-MG3",
			"R-Defense-WallTower-MG3",
			"R-Defense-WallTower-MG3Twin",
			"R-Defense-Tower2-MG4",
			"R-Defense-Bunker2-MG4",
			"R-Defense-WallTower2-MG4",
			"R-Defense-Super-Machinegun",
			"R-Defense-WallTower2-MG5",
			"R-Defense-Bunker2-MG5",
			"R-Defense-Bunker-MG3Inc",
			"R-Defense-WallTower-MG3Inc",
			"R-Defense-Bunker-MG3IncTwin",
			"R-Defense-WallTower-MG3IncTwin",
			"R-Defense-Bunker3-MG4Inc",
			"R-Defense-WallTower3-MG4Inc",
			"R-Defense-Bunker3-MG4IncTwin",
			"R-Defense-WallTower3-MG4IncTwin",
			"R-Defense-Super-MachinegunPlas",
			"R-Defense-Bunker2-Laser-AP1",
			"R-Defense-Tower2-Laser-AP1",
			"R-Defense-WallTower2-Laser-AP1",
			"R-Defense-Bunker2-Laser-AP2",
			"R-Defense-WallTower2-Laser-AP2",
			"R-Defense-Bunker3-Laser-AP3",
			"R-Defense-Tower3-Laser-AP3",
			"R-Defense-WallTower3-Laser-AP3",
			"R-Defense-Bunker3-Laser-AP4",
			"R-Defense-WallTower3-Laser-AP4",
			"R-Defense-Super-Laser",
		];
		
		this.researchPathAA = [
			"R-Defense-Bunker-MG-AA",
			"R-Defense-Bunker2-MG-AA2",
			"R-Defense-Bunker-Laser-AA",
			"R-Defense-Bunker3-Laser-AA2",
		];
		
		this.researchPathAB = [
			"R-Defense-Bunker-Mortar",
			"R-Defense-Bunker2-Howitzer",
			"R-Defense-Bunker2-HowitzerHvy",
			"R-Defense-Super-Mortar",
			"R-Defense-Super-Howitzer",
			"R-Defense-Super-MortarGauss",
			"R-Defense-Super-HowitzerGauss",
			"R-Wpn-Laser-Sonic-TankDest",
		];

	break;
	case 1:

		this.tankBodies = [ contingencyBodiesLightCheap, ];

		this.tankPropulsions = [
		[
			"hover01", // hovers
			"HalfTrack", // half-track
			"wheeled01", // wheels
		],
		];

		this.apWeapons = [
		[
			"Laser-AP4",
			"Laser-AP3",
			"Laser-AP2",
			"Laser-AP1",
			"PlasmiteFlamer",
			"Flame2",
			"Flame1Mk1",
			"MG1Mk1",
		],
		[
			"Flamer-PlasmaCannon",
			"PlasmiteFlamer",
			"Flame2",
			"Flame1Mk1",
			"Cannon1Mk1",
			"MG1Mk1",
		],
		];
		
		this.atWeapons = [
		[
			"Laser-AT4",
			"Laser-AT3",
			"Laser-AT2",
			"Laser-AT1",
			"PlasmiteFlamer",
			"Flame2",
			"Cannon1Mk1",
			"Flame1Mk1",
			"MG1Mk1",
		],
		[
			"Laser-TankDest2",
			"Laser-TankDest",
			"PlasmiteFlamer",
			"Flame2",
			"Flame1Mk1",
			"Cannon1Mk1",
			"MG1Mk1",
		],
		[
			"Flamer-PlasCan-TankDest",
			"PlasmiteFlamer",
			"Flame2",
			"Flame1Mk1",
			"Cannon1Mk1",
			"MG1Mk1",
		],
		];

		this.abWeapons = this.abWeapons.concat([
		[
			"Laser-Sonic-TankDest",
			"Laser-Sonic",
		],
		]);
		
		this.aaWeapons = [
		[
			"Laser-AA2",
			"Laser-AA",
			"MG-AA2",
			"MG-AA",
		],
		];
		
		this.apCyborgStats = [
		[
			["Cyb-Bod-Laser-AP3","Cyb-Wpn-Laser-AP3","CyborgLegs"],
			["Cyb-Bod-MG4Inc","Cyb-Wpn-MG4Inc","CyborgLegs"],
			["Cyb-Bod-Laser-AP1","Cyb-Wpn-Laser-AP1","CyborgLegs"],
			["Cyb-Bod-MG3Inc","Cyb-Wpn-MG3Inc","CyborgLegs"],
			["Cyb-Bod-Thermite","Cyb-Wpn-Thermite","CyborgLegs"],
			["CyborgFlamerGrd","CyborgFlamer01","CyborgLegs"],
			["CyborgChain1Ground","CyborgChaingun","CyborgLegs"],
		],
		[
			["HvyCyb-Bod-Laser-AP3","HvyCyb-Wpn-Laser-AP3","HvyCyborgLegs"],
			["HvyCyb-Bod-Flamer3","HvyCyb-Wpn-Flamer3","HvyCyborgLegs"],
			["HvyCyb-Bod-Laser-AP1","HvyCyb-Wpn-Laser-AP1","HvyCyborgLegs"],
			["HvyCyb-Bod-Flamer2","HvyCyb-Wpn-Flamer2","HvyCyborgLegs"],
			["HvyCyb-Bod-Flamer1","HvyCyb-Wpn-Flamer1","HvyCyborgLegs"],
			["CyborgChain1Ground","CyborgChaingun","CyborgLegs"],
		],
		[
			["Cyb-Bod-Laser-AP3","Cyb-Wpn-Laser-AP3","CyborgLegs"],
			["HvyCyb-Bod-Laser-AP1","HvyCyb-Wpn-Laser-AP1","HvyCyborgLegs"],
			["Cyb-Bod-MortarInc","Cyb-Wpn-MortarInc","CyborgLegs"],
			["Cyb-Bod-Thermite","Cyb-Wpn-Thermite","CyborgLegs"],
			["CyborgFlamerGrd","CyborgFlamer01","CyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		];

		this.atCyborgStats = [
		[
			["HvyCyb-Bod-Laser-AT3","HvyCyb-Wpn-Laser-AT3","HvyCyborgLegs"],
			["HvyCyb-Bod-Laser-AT1","HvyCyb-Wpn-Laser-AT1","HvyCyborgLegs"],
			["HvyCyb-Bod-Flamer3","HvyCyb-Wpn-Flamer3","HvyCyborgLegs"],
			["HvyCyb-Bod-Flamer2","HvyCyb-Wpn-Flamer2","HvyCyborgLegs"],
			["HvyCyb-Bod-Flamer1","HvyCyb-Wpn-Flamer1","HvyCyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		[
			["Cyb-Bod-Laser-AT3","Cyb-Wpn-Laser-AT3","CyborgLegs"],
			["Cyb-Bod-Thermite","Cyb-Wpn-Thermite","CyborgLegs"],
			["Cyb-Bod-Laser-AT1","Cyb-Wpn-Laser-AT1","CyborgLegs"],
			["CyborgFlamerGrd","CyborgFlamer01","CyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		[
			["HvyCyb-Bod-Laser-AT3","HvyCyb-Wpn-Laser-AT3","HvyCyborgLegs"],
			["Cyb-Bod-MortarInc","Cyb-Wpn-MortarInc","CyborgLegs"],
			["Cyb-Bod-Thermite","Cyb-Wpn-Thermite","CyborgLegs"],
			["Cyb-Bod-Laser-AT1","Cyb-Wpn-Laser-AT1","CyborgLegs"],
			["CyborgFlamerGrd","CyborgFlamer01","CyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		];
		
		this.aaCyborgStats = [
		[
			["Cyb-Bod-Laser-AP3","Cyb-Wpn-Laser-AP3","CyborgLegs"],
			["Cyb-Bod-MG4Inc","Cyb-Wpn-MG4Inc","CyborgLegs"],
			["Cyb-Bod-Laser-AP1","Cyb-Wpn-Laser-AP1","CyborgLegs"],
			["Cyb-Bod-MG3Inc","Cyb-Wpn-MG3Inc","CyborgLegs"],
			["CybRotMgGrd","CyborgRotMG","CyborgLegs"],
			["CyborgChain1Ground","CyborgChaingun","CyborgLegs"],
		],
		[
			["HvyCyb-Bod-Laser-AP3","HvyCyb-Wpn-Laser-AP3","HvyCyborgLegs"],
			["HvyCyb-Bod-MG4Inc","HvyCyb-Wpn-MG4Inc","HvyCyborgLegs"],
			["HvyCyb-Bod-MG3Inc","HvyCyb-Wpn-MG3Inc","HvyCyborgLegs"],
			["HvyCyb-Bod-Laser-AP1","HvyCyb-Wpn-Laser-AP1","HvyCyborgLegs"],
			["HvyCyb-Bod-MG4","HvyCyb-Wpn-MG4","HvyCyborgLegs"],
			["HvyCyb-Bod-MG3","HvyCyb-Wpn-MG3","HvyCyborgLegs"],
		],
		];

		this.vtolBodies = [contingencyBodiesVtol,];

		this.vtolWeapons = [
		[
			"Bomb-Earthquake",
			"Bomb-FuelAir",
			"Bomb5-VTOL-Plasmite",
			"Bomb4-VTOL-HvyINC",
			"Bomb2-VTOL-HvHE",
			"Bomb3-VTOL-LtINC",
			"Bomb1-VTOL-LtHE",
		],
		];

		this.defenses = [
		[
			"Tower3-Laser-AP3",
			"Tower2-Laser-AP1",
		],
		[
			"Bunker3-Laser-AP4",
			"Bunker3-Laser-AP3",
			"Bunker2-Laser-AP2",
			"Bunker2-Laser-AP1",
		],
		[
			"Bunker3-Laser-AT4",
			"Bunker3-Laser-AT3",
			"Bunker2-Laser-AT2",
			"Bunker2-Laser-AT1",
		],
		[
			"Tower3-Laser-AT3",
			"Tower2-Laser-AT1",
		],
		[
			"Super-Laser2-Fort",
			"Super-Laser-Fort",
		],
		];

		this.artillery = [
		[
			"Bunker2-HowitzerInc",
			"Bunker2-Howitzer",
			"Bunker-MortarInc",
			"Bunker-Mortar",
		],
		[
			"Emplacement-Howitzer-Incenediary",
			"Emplacement-Howitzer105",
			"Emplacement-MortarPit-Incenediary",
			"Emplacement-MortarPit01",
		],
		[
			"Super-HowitzerPlas-Empl",
			"Super-Howitzer-Empl",
			"Super-MortarPlas-Empl",
			"Super-Mortar-Empl",
		],
		];

		this.antiair = [
		[
			"WallTower3-Laser-AA2",
			"WallTower-Laser-AA",
			"WallTower2-MG-AA2",
			"WallTower-MG-AA",
		],
		];

		this.hardpoints = [
		[
			"WallTower3-Laser-AP4",
			"WallTower3-Laser-AP3",
			"WallTower2-Laser-AP2",
			"WallTower2-Laser-AP1",
		],
		[
			"WallTower3-Laser-AT4",
			"WallTower3-Laser-AT3",
			"WallTower2-Laser-AT2",
			"WallTower2-Laser-AT1",
		],
		];
		
		this.researchPathPrimary = [
			"R-Wpn-Cannon-Damage01",
			"R-Vehicle-Prop-Halftracks",
			"R-Wpn-Flamer-ROF01",
			"R-Struc-PowerModuleMk1",
			"R-Struc-Factory-Cyborg",
			"R-Vehicle-Body04",
			"R-Vehicle-Prop-Halftracks",
			"R-Wpn-Flame2",
			"R-Defense-Empl-MortarInc",
			"R-Struc-Research-Upgrade05",
			"R-Struc-PowerModuleMk1",
			"R-Wpn-Plasmite-Flamer",
		];
		
		this.researchPathAT = [
			"R-Wpn-Flamer-PlasCan-TankDest",
			"R-Defense-Bunker2-Laser-AT1",
			"R-Defense-Tower2-Laser-AT1",
			"R-Defense-WallTower2-Laser-AT1",
			"R-Defense-Bunker2-Laser-AT2",
			"R-Defense-WallTower2-Laser-AT2",
			"R-Defense-Bunker3-Laser-AT3",
			"R-Defense-Tower3-Laser-AT3",
			"R-Defense-WallTower3-Laser-AT3",
			"R-Defense-Bunker3-Laser-AT4",
			"R-Defense-WallTower3-Laser-AT4",
			"R-Defense-Super-Laser",
		];
		
		this.researchPathAP = [
			"R-Wpn-Flamer-PlasmaCannon",
			"R-Defense-Bunker2-Laser-AP1",
			"R-Defense-Tower2-Laser-AP1",
			"R-Defense-WallTower2-Laser-AP1",
			"R-Defense-Bunker2-Laser-AP2",
			"R-Defense-WallTower2-Laser-AP2",
			"R-Defense-Bunker3-Laser-AP3",
			"R-Defense-Tower3-Laser-AP3",
			"R-Defense-WallTower3-Laser-AP3",
			"R-Defense-Bunker3-Laser-AP4",
			"R-Defense-WallTower3-Laser-AP4",
			"R-Defense-Super-Laser",
		];
		
		this.researchPathAA = [
			"R-Defense-WallTower-MG-AA",
			"R-Defense-WallTower2-MG-AA2",
			"R-Defense-WallTower-Laser-AA",
			"R-Defense-WallTower3-Laser-AA2",
		];
		
		this.researchPathAB = [
			"R-Defense-Empl-MortarInc",
			"R-Defense-Super-MortarPlas",
			"R-Defense-Empl2-HowitzerInc",
			"R-Defense-Super-HowitzerPlas",
			"R-Wpn-Bomb-Earthquake",
			"R-Wpn-Laser-Sonic-TankDest",
		];

	break;
	case 2:

		this.tankBodies = [ contingencyBodiesLightCheap, ];

		this.tankPropulsions = [
		[
			"tracked01", // tracks
			"HalfTrack", // half-track
			"wheeled01", // wheels
		],
		];

		this.atWeapons = [
		[
			"Railgun-GattlingAT",
			"Railgun-TankDest",
			"Railgun-Aslt",
			"Railgun-ProtoTankDest",
			"Railgun-Proto",
			"Cannon-HPVGattling",
			"Cannon-HPVHvy",
			"Cannon-HPVTwinAslt",
			"Cannon-HPVTankDest",
			"Cannon-HPVAslt",
			"Cannon-TankDest",
			"Cannon4AUTOMk1",
			"Cannon-HPVLgt",
			"Cannon2A-TMk1",
			"Cannon1Mk1",
		],
		];
		
		this.apWeapons = [
		[
			"Railgun-GattlingTwin",
			"Railgun-Shotgun",
			"Railgun-Gattling",
			"Railgun-TwinAslt",
			"Railgun-Proto",
			"Cannon-Shotgun",
			"Cannon-Gattling",
			"Cannon6TwinAslt",
			"Cannon375mmMk1",
			"Cannon5VulcanMk1",
			"Cannon2A-TMk1",
			"Cannon1Mk1",
		],
		[
			"SpyTurret03",
			"SpyTurret02",
			"SpyTurret01",
		],
		];
		
		// this.abWeapons already defined above.
		
		this.aaWeapons = [
		[
			"Railgun-GattlingAA",
			"Railgun-Flak",
			"AAGun2Mk1",
		],
		];
		
		this.atCyborgStats = [
		[
			["Cyb-Bod-Rail1","Cyb-Wpn-Rail1","CyborgLegs"],
			["Cyb-Hvybod-RailGunner","Cyb-Hvywpn-RailGunner","HvyCyborgLegs"],
			["HvyCyb-Bod-Cannon-HPVAslt","HvyCyb-Wpn-Cannon-HPVAslt","HvyCyborgLegs"],
			["Cyb-Hvybod-HPV","Cyb-Hvywpn-HPV","HvyCyborgLegs"],
			["Cyb-Hvybod-Mcannon","Cyb-Hvywpn-Mcannon","HvyCyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		[
			["HvyCyb-Bod-Railgun-Aslt","HvyCyb-Wpn-Railgun-Aslt","HvyCyborgLegs"],
			["Cyb-Bod-Rail1","Cyb-Wpn-Rail1","CyborgLegs"],
			["HvyCyb-Bod-Railgun-Gattling","HvyCyb-Bod-Railgun-GattlingInc","HvyCyborgLegs"],
			["Cyb-Bod-Cannon-HPVLgt","Cyb-Wpn-Cannon-HPVLgt","CyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		];
		
		this.apCyborgStats = [
		[
			["Cyb-Bod-Railgun-Sniper","Cyb-Wpn-Railgun-Sniper","CyborgLegs"],
			["HvyCyb-Bod-Cannon-Shotgun","HvyCyb-Wpn-Cannon-Shotgun","HvyCyborgLegs"],
			["HvyCyb-Bod-MortarRot","HvyCyb-Wpn-MortarRot","HvyCyborgLegs"],
			["Cyb-Bod-Cannon-Sniper","Cyb-Wpn-Cannon-Sniper","CyborgLegs"],
			["Cyb-Bod-Grenade","Cyb-Wpn-Grenade","CyborgLegs"],
			["Cyb-Hvybod-Acannon","Cyb-Hvywpn-Acannon","HvyCyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		[
			["HvyCyb-Bod-Railgun-Shotgun","HvyCyb-Wpn-Railgun-Shotgun","HvyCyborgLegs"],
			["HvyCyb-Bod-Cannon-Shotgun","HvyCyb-Wpn-Cannon-Shotgun","HvyCyborgLegs"],
			["HvyCyb-Bod-MortarRot","HvyCyb-Wpn-MortarRot","HvyCyborgLegs"],
			["Cyb-Bod-Grenade","Cyb-Wpn-Grenade","CyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		];

		this.aaCyborgStats = [
		[
			["Cyb-Bod-Laser-AP3","Cyb-Wpn-Laser-AP3","CyborgLegs"],
			["Cyb-Bod-MG4Inc","Cyb-Wpn-MG4Inc","CyborgLegs"],
			["Cyb-Bod-Laser-AP1","Cyb-Wpn-Laser-AP1","CyborgLegs"],
			["Cyb-Bod-MG3Inc","Cyb-Wpn-MG3Inc","CyborgLegs"],
			["CybRotMgGrd","CyborgRotMG","CyborgLegs"],
			["CyborgChain1Ground","CyborgChaingun","CyborgLegs"],
		],
		[
			["HvyCyb-Bod-Laser-AP3","HvyCyb-Wpn-Laser-AP3","HvyCyborgLegs"],
			["HvyCyb-Bod-MG4Inc","HvyCyb-Wpn-MG4Inc","HvyCyborgLegs"],
			["HvyCyb-Bod-MG3Inc","HvyCyb-Wpn-MG3Inc","HvyCyborgLegs"],
			["HvyCyb-Bod-Laser-AP1","HvyCyb-Wpn-Laser-AP1","HvyCyborgLegs"],
			["HvyCyb-Bod-MG4","HvyCyb-Wpn-MG4","HvyCyborgLegs"],
			["HvyCyb-Bod-MG3","HvyCyb-Wpn-MG3","HvyCyborgLegs"],
		],
		];

		this.vtolBodies = [contingencyBodiesVtol,];

		this.vtolWeapons = [
		[
			"Bomb-Earthquake",
			"Railgun-GattlingInc-VTOL",
			"Railgun-Gattling-VTOL",
			"Railgun-Aslt-VTOL",
			"Bomb-FuelAir",
			"Bomb5-VTOL-Plasmite",
			"Railgun-Shotgun-VTOL",
			"Bomb4-VTOL-HvyINC",
			"Cannon-HPVAslt-VTOL",
			"Cannon5Vulcan-VTOL",
			"Bomb2-VTOL-HvHE",
			"Cannon4AUTO-VTOL",
			"Cannon-HPVLgt-VTOL",
			"Cannon-Med-VTOL",
			"Bomb3-VTOL-LtINC",
			"Bomb1-VTOL-LtHE",
			"Cannon-Shotgun-VTOL",
			"Cannon1-VTOL",
		],
		];

		this.defenses = [
		[
			"Bunker3-Railgun-TwinAslt",
			"Bunker3-Railgun-Hvy",
			"Bunker3-Railgun-Aslt",
			"Bunker3-Railgun-Med",
			"Bunker2-Cannon-Gattling",
			"Bunker3-Railgun-Lgt",
			"PillBox-Cannon6",
			"Bunker2-Railgun-Proto",
			"Bunker-Cannon-Hvy",
			"Bunker-Railgun-Proto",
			"Bunker-Cannon-Aslt",
			"Bunker-Cannon-Med",
			"PillBox4",
		],
		[
			"Bunker4-Railgun-GattlingAT",
			"Bunker3-Cannon-HPVGattling",
			"Bunker3-Cannon-Ramjet",
			"Bunker2-Cannon-HPVTwinAslt",
			"Bunker2-Cannon-HPVAslt",
			"Bunker2-Cannon-HPVHvy",
			"Bunker2-Cannon-HPVMed",
			"Bunker2-Cannon-HPVLgt",
		],
		[
			"Bunker4-Railgun-GattlingInc",
			"Bunker4-Railgun-Gattling",
			"Bunker3-Railgun-GattlingIncTwin",
			"Bunker3-Railgun-GattlingTwin",
			"Bunker3-Railgun-GattlingInc",
			"Bunker3-Railgun-Gattling",
			"Bunker3-Railgun-Shotgun",
			"Bunker4-Flamer-PlasmaCannon",
			"Bunker2-Cannon-Shotgun",
			"Bunker2-Cannon-Inc",
		],
		[
			"Tower-Cannon-Aslt",
			"Tower-Cannon-Med",
			"Tower-Cannon-Lgt",
		],
		[
			"Tower3-Railgun-Aslt",
			"Tower3-Railgun-Med",
			"GuardTower-Rail1",
			"Tower2-Cannon-HPVAslt",
			"Tower-VulcanCan",
			"Tower2-Cannon-HPVLgt",
		],
		[
			"Tower3-Railgun-GattlingIncTwin",
			"Tower3-Railgun-GattlingTwin",
			"Tower4-Railgun-GattlingInc",
			"Tower3-Railgun-GattlingInc",
			"Tower3-Railgun-Shotgun",
			"Tower4-Railgun-Gattling",
			"Tower3-Railgun-Gattling",
			"Tower2-Cannon-Shotgun",
		],
		[
			"Super-RailgunGattlingPlas-Fort2",
			"Super-RailgunGattling-Fort2",
			"Super-RailgunGattlingPlas-Fort",
			"Super-Railgun-Fort",
			"Super-PlasCannon-Fort",
			"Super-RailgunGattling-Fort",
			"Super-RotCannon-Fort",
			"X-Super-Cannon",
		],
		];

		this.artillery = [
		[
			"Super-MortarGauss-Empl",
			"Bunker4-HowitzerGauss",
			"Super-Mortar-Empl",
			"Bunker2-Howitzer",
			"Bunker-Mortar",
		],
		[
			"Super-HowitzerGauss-Empl",
			"Bunker4-HowitzerGaussHvy",
			"Super-Howitzer-Empl",
			"Bunker2-HowitzerHvy",
			"Emplacement-Howitzer105",
			"Emplacement-MortarPit01",
		],
		[
			"Bunker4-HowitzerGaussHvy",
			"Bunker2-HowitzerHvy",
			"Emplacement-Howitzer105",
			"Emplacement-MortarPit01",
		],
		];


		this.antiair = [
		[
			"WallTower4-Railgun-GattlingAA",
			"Bunker4-Railgun-GattlingAA",
			"Empl4-Railgun-GattlingAA",
			"Bunker3-Railgun-GattlingAA",
			"WallTower3-Railgun-GattlingAA",
			"WallTower3-Railgun-Flak",
			"Bunker3-Railgun-Flak",
			"Empl3-Railgun-Flak",
			"WallTower-DoubleAAGun",
			"Bunker-Cannon-Flak",
			"AASite-QuadBof",
		],
		];

		this.hardpoints = [
		[
			"WallTower3-Railgun-TwinAslt",
			"WallTower3-Railgun-Aslt",
			"WallTower-Rail3",
			"WallTower-Rail2",
 			"WallTower3-Railgun-Lgt",
			"WallTower2-Railgun-Proto",
			"WallTower-Railgun-Proto",
			"WallTower2-Cannon-Gattling",
			"WallTower-Cannon-TwinAslt",
			"Wall-VulcanCan",
			"WallTower04",
			"WallTower03",
			"WallTower02",
		],
		[
			"WallTower4-Railgun-GattlingAT",
			"WallTower2-Railgun-Proto",
			"WallTower3-Cannon-Ramjet",
			"WallTower3-Cannon-HPVGattling",
			"WallTower2-Cannon-HPVTwinAslt",
			"WallTower2-Cannon-HPVHvy",
			"WallTower2-Cannon-HPVAslt",
			"WallTower-HPVcannon",
			"WallTower2-Cannon-HPVLgt",
		],
		[
			"WallTower3-Railgun-GattlingIncTwin",
			"WallTower3-Railgun-GattlingTwin",
			"WallTower4-Railgun-GattlingInc",
			"WallTower3-Railgun-GattlingInc",
			"WallTower3-Railgun-Shotgun",
			"WallTower4-Railgun-Gattling",
			"WallTower3-Railgun-Gattling",
			"WallTower4-Flamer-PlasmaCannon",
			"WallTower3-Cannon-Plas",
			"WallTower2-Cannon-Shotgun",
			"WallTower2-Cannon-Inc",
		],
		];
		
		this.researchPathPrimary = [
			"R-Wpn-Cannon-Damage01",
			"R-Vehicle-Prop-Halftracks",
			"R-Vehicle-Body04",
			"R-Struc-PowerModuleMk1",
			"R-Struc-Factory-Cyborg",
			
		];

		this.researchPathAT = [
			"R-Defense-Bunker2-Cannon-HPVLgt",
			"R-Defense-Tower2-Cannon-HPVLgt",
			"R-Defense-WallTower2-Cannon-HPVLgt",
			"R-Defense-Bunker2-Cannon-HPVMed",
			"R-Defense-WallTower2-Cannon-HPVMed",
			"R-Defense-Tower2-Cannon-HPVMed",
			"R-Defense-Bunker2-Cannon-HPVHvy",
			"R-Defense-Tower2-Cannon-HPVAslt",
			"R-Defense-WallTower2-Cannon-HPVAslt",
			"R-Defense-Bunker2-Cannon-HPVAslt",
			"R-Defense-Bunker2-Cannon-HPVTwinAslt",
			"R-Defense-Bunker3-Cannon-HPVGattling",
			"R-Defense-WallTower2-Cannon-HPVTwinAslt",
			"R-Defense-WallTower2-Cannon-HPVHvy",
			"R-Defense-WallTower3-Cannon-HPVGattling",
			"R-Defense-Super-Cannon",
			"R-Defense-Super-RotCannon",
			"R-Defense-WallTower4-Railgun-GattlingAT",
			"R-Defense-Bunker4-Railgun-GattlingAT",
			"R-Defense-WallTower-Railgun-Proto",
			"R-Defense-WallTower2-Railgun-Proto",
			"R-Defense-WallTower3-Railgun-Lgt",
			"R-Defense-WallTower3-Railgun-Med",
			"R-Defense-WallTower3-Railgun-Hvy",
			"R-Defense-WallTower3-Railgun-Aslt",
			"R-Defense-WallTower3-Railgun-TwinAslt",
			"R-Defense-Tower3-Railgun-Gattling",
			"R-Defense-WallTower3-Railgun-Gattling",
			"R-Defense-Tower3-Railgun-GattlingTwin",
			"R-Defense-WallTower3-Railgun-GattlingTwin",
			"R-Defense-Tower4-Railgun-Gattling",
			"R-Defense-WallTower4-Railgun-Gattling",
			"R-Defense-Super-RailgunGattling",
			"R-Defense-Super-RailgunGattling2",
			"R-Defense-Super-RotRailgun",
		];
		
		this.researchPathAP = [
			"R-Sys-SpyTurret",
			"R-Defense-Bunker2-Cannon-Shotgun",
			"R-Defense-WallTower2-Cannon-Shotgun",
			"R-Defense-WallTower-Cannon-Lgt",
			"R-Defense-WallTower-Cannon-Med",
			"R-Defense-WallTower-Cannon-Hvy",
			"R-Defense-Bunker-Cannon-Lgt",
			"R-Defense-Tower-Cannon-Lgt",
			"R-Defense-Bunker-Cannon-Med",
			"R-Defense-Tower-Cannon-Med",
			"R-Defense-Tower-Cannon-Aslt",
			"R-Defense-WallTower-Cannon-Aslt",
			"R-Defense-WallTower-Cannon-TwinAslt",
			"R-Defense-Bunker-Cannon-Aslt",
			"R-Defense-Bunker-Cannon-Hvy",
			"R-Defense-Bunker-Cannon-TwinAslt",
			"R-Defense-Bunker2-Cannon-Gattling",
			"R-Defense-WallTower2-Cannon-Gattling",
			"R-Sys-SpyTurret02",
			"R-Defense-Super-Cannon",
			"R-Defense-Super-RotCannon",
			"R-Defense-Bunker3-Railgun-Gattling",
			"R-Defense-Bunker3-Railgun-GattlingTwin",
			"R-Defense-Bunker-Railgun-Proto",
			"R-Defense-Bunker2-Railgun-Proto",
			"R-Defense-Bunker3-Railgun-Lgt",
			"R-Defense-Bunker3-Railgun-Med",
			"R-Defense-Bunker3-Railgun-Hvy",
			"R-Defense-Bunker3-Railgun-Aslt",
			"R-Defense-Bunker3-Railgun-TwinAslt",
			"R-Defense-Bunker3-Railgun-Shotgun",
			"R-Sys-SpyTurret03",
			"R-Defense-Super-RailgunGattling",
			"R-Defense-Super-RailgunGattling2",
			"R-Defense-Super-RotRailgun",
		];
		
		this.researchPathAA = [
			"R-Defense-Bunker-Cannon-Flak",
			"R-Defense-Bunker3-Railgun-Flak",
			"R-Defense-Bunker3-Railgun-GattlingAA",
			"R-Defense-Bunker4-Railgun-GattlingAA",
		];
		
		this.researchPathAB = [
			"R-Defense-Bunker-Mortar",
			"R-Defense-Super-Mortar",
			"R-Defense-Bunker2-Howitzer",
			"R-Defense-Super-Howitzer",
			"R-Defense-Bunker2-HowitzerHvy",
			"R-Defense-Bunker4-HowitzerGaussHvy",
			"R-Defense-Super-MortarGauss",
			"R-Defense-Super-HowitzerGauss",
			"R-Wpn-Bomb-Earthquake",
		];
	
	break;
	case 3:

		this.tankBodies = [contingencyBodiesSuperArmored,];
		this.tankBodies[0] = this.tankBodies[0].concat(contingencyBodiesHeavyArmored,contingencyBodiesMediumArmored,contingencyBodiesLightArmored);
	
		this.tankBodiesLight = [contingencyBodiesLightArmored,];
		this.tankBodiesMedium = [contingencyBodiesMediumArmored,];
		this.tankBodiesHeavy = [contingencyBodiesHeavyArmored,];
		this.tankBodiesSuper = [contingencyBodiesSuperArmored,];
		
		sensorBodies = this.tankBodies[0];

		this.tankPropulsions = [
		[
			"tracked01", // tracks
			"HalfTrack", // half-track
			"wheeled01", // wheels
		],
		];

		sensorPropulsions = this.tankPropulsions[0];

		this.apWeapons = [
		[
		],
		];

		this.apWeaponsLight = [
		[
			"Rocket-Pod3",
			"Rocket-Pod2",
			"Rocket-Pod",
			"Cannon1Mk1",
			"MG1Mk1",
		],
		];

		this.apWeaponsMedium = [
		[
			"Missile-MdArt",
			"Rocket-TopAttack",
			"Rocket-MRL",
		],
		[
			"Missile-MdArt",
			"Rocket-TopAttack",
			"Rocket-MRL",
		],
		[
			"Rocket-Pod3Twin",
			"Rocket-Pod2Twin",
			"Rocket-PodTwin",
			"Rocket-Pod",
			"Cannon1Mk1",
			"MG1Mk1",
		],
		];

		this.apWeaponsHeavy = [
		[
			"Missile-MdArtHvy",
			"Rocket-TopAttackHvy",
			"Rocket-MRLHvy",
			"Rocket-MRL",
		],
		[
			"Missile-MdArtHvy",
			"Rocket-TopAttackHvy",
			"Rocket-MRLHvy",
			"Rocket-MRL",
		],
		[
			"Rocket-Pod3Quad",
			"Rocket-Pod2Quad",
			"Rocket-PodQuad",
			"Rocket-PodTwin",
			"Rocket-Pod",
			"Cannon1Mk1",
			"MG1Mk1",
		],
		];

		this.apWeaponsSuper = [
		[
			"Rocket-Gattling",
		],
		];

		this.atWeapons = [
		[
		],
		];

		this.atWeaponsLight = [
		[
			"Rocket-Pod3",
			"Rocket-Pod2",
			"Rocket-Pod",
			"Cannon1Mk1",
		],
		];

		this.atWeaponsMedium = [
		[
			"Missile-A-T",
			"Rocket-HvyA-T",
			"Rocket-LtA-T",
		],
		[
			"Missile-A-T",
			"Rocket-HvyA-T",
			"Rocket-LtA-T",
		],
		[
			"Rocket-Pod3Twin",
			"Rocket-Pod2Twin",
			"Rocket-PodTwin",
			"Rocket-Pod",
			"Cannon1Mk1",
		],
		];

		this.atWeaponsHeavy = [
		[
			"Missile-A-THvy",
			"Rocket-HvyA-THvy",
			"Rocket-LtA-THvy",
			"Rocket-LtA-T",
		],
		[
			"Missile-A-THvy",
			"Rocket-HvyA-THvy",
			"Rocket-LtA-THvy",
			"Rocket-LtA-T",
		],
		[
			"Rocket-Pod3Quad",
			"Rocket-Pod2Quad",
			"Rocket-PodQuad",
			"Rocket-PodTwin",
			"Rocket-Pod",
			"Cannon1Mk1",
		],
		];

		this.atWeaponsSuper = [
		[
		],
		];

		this.abWeapons = [
		[
		],
		];

		this.abWeaponsLight = [
		[
		],
		];

		this.abWeaponsMedium = [
		[
			"Rocket-BB2",
			"Rocket-BB",
			"Rocket-HvyA-T",
			"Rocket-LtA-T",
		],
		];

		this.abWeaponsHeavy = [
		[
			"Rocket-BB2",
			"Rocket-BB",
			"Rocket-HvyA-THvy",
			"Rocket-LtA-THvy",
			"Rocket-LtA-T",
		],
		];

		this.abWeaponsSuper = [
		[
		],
		];

		this.aaWeapons = [
		[
		],
		];

		this.aaWeaponsLight = [
		[
			"Rocket-Pod3",
			"Rocket-Pod2",
			"Rocket-Pod",
		],
		];

		this.aaWeaponsMedium = [
		[
			"Missile-LtSAM2",
			"Missile-LtSAM",
		],
		[
			"Rocket-Cherub",
			"Rocket-Sunburst",
			"Rocket-Pod3Twin",
			"Rocket-Pod2Twin",
			"Rocket-PodTwin",
			"Rocket-Pod",
		],
		];

		this.aaWeaponsHeavy = [
		[
			"Missile-HvySAM2",
			"Missile-HvySAM",
			"Missile-LtSAM",
			"Rocket-Pod3Quad",
			"Rocket-Pod2Quad",
			"Rocket-PodQuad",
			"Rocket-PodTwin",
			"Rocket-Pod",
		],
		];

		this.aaWeaponsSuper = [
		[
			"Rocket-Gattling",
		],
		];

		this.harassWeapons = [
		[
			"SpyTurretNEXUS",
			"SpyTurret03",
			"SpyTurret02",
			"SpyTurret01",
			"Missile-MdArt",
			"Rocket-TopAttack",
			"Rocket-MRL",
			"Rocket-BB2",
			"Rocket-BB",
			"Rocket-HvyA-T",
			"Rocket-LtA-T",
			"Rocket-Pod3",
			"Rocket-Pod2",
			"Rocket-Pod",
			"Cannon1Mk1",
			"MG1Mk1",
		],
		];
	
		this.apCyborgStats = [
		[
			["HvyCyb-Bod-Missile-MdArt","HvyCyb-Wpn-Missile-MdArt","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-TopAttack","HvyCyb-Wpn-Rocket-TopAttack","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-MRL","HvyCyb-Wpn-Rocket-MRL","HvyCyborgLegs"],
		],
		[
			["HvyCyb-Bod-Rocket-Pod3","HvyCyb-Wpn-Rocket-Pod3","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-Pod2","HvyCyb-Wpn-Rocket-Pod2","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-Pod","HvyCyb-Wpn-Rocket-Pod","HvyCyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
			["CyborgChain1Ground","CyborgChaingun","CyborgLegs"],
		],
		[
			["HvyCyb-Bod-Missile-MdArt","HvyCyb-Wpn-Missile-MdArt","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-TopAttack","HvyCyb-Wpn-Rocket-TopAttack","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-MRL","HvyCyb-Wpn-Rocket-MRL","HvyCyborgLegs"],
		],
		];

		this.atCyborgStats = [
		[
			["Cyb-Hvybod-A-T","Cyb-Hvywpn-A-T","HvyCyborgLegs"],
			["Cyb-Hvybod-TK","Cyb-Hvywpn-TK","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-LtA-T","HvyCyb-Wpn-Rocket-LtA-T","HvyCyborgLegs"],
		],
		[
			["HvyCyb-Bod-Rocket-Pod3","HvyCyb-Wpn-Rocket-Pod3","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-Pod2","HvyCyb-Wpn-Rocket-Pod2","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-Pod","HvyCyb-Wpn-Rocket-Pod","HvyCyborgLegs"],
			["CyborgCannonGrd","CyborgCannon","CyborgLegs"],
		],
		[
			["Cyb-Bod-Atmiss","Cyb-Wpn-Atmiss","CyborgLegs"],
			["Cyb-Bod-Rocket-HvyA-T","Cyb-Wpn-Rocket-HvyA-T","CyborgLegs"],
			["CyborgRkt1Ground","CyborgRocket","CyborgLegs"],
		],
		];

		this.abCyborgStats = [
		[
			["Cyb-Hvybod-A-T","Cyb-Hvywpn-A-T","HvyCyborgLegs"],
			["Cyb-Hvybod-TK","Cyb-Hvywpn-TK","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-LtA-T","HvyCyb-Wpn-Rocket-LtA-T","HvyCyborgLegs"],
		],
		[
			["Cyb-Bod-Atmiss","Cyb-Wpn-Atmiss","CyborgLegs"],
			["Cyb-Bod-Rocket-HvyA-T","Cyb-Wpn-Rocket-HvyA-T","CyborgLegs"],
			["CyborgRkt1Ground","CyborgRocket","CyborgLegs"],
		],
		];

		this.aaCyborgStats = [
		[
			["HvyCyb-Bod-Missile-HvySAM","HvyCyb-Wpn-Missile-HvySAM","HvyCyborgLegs"],
			["HvyCyb-Bod-Missile-LtSAM","HvyCyb-Wpn-Missile-LtSAM","HvyCyborgLegs"],
		],
		[
			["Cyb-Bod-Rocket-Cherub","Cyb-Wpn-Rocket-Cherub","CyborgLegs"],
			["Cyb-Bod-Rocket-Sunburst","Cyb-Wpn-Rocket-Sunburst","CyborgLegs"],
			["HvyCyb-Bod-Rocket-Pod3","HvyCyb-Wpn-Rocket-Pod3","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-Pod2","HvyCyb-Wpn-Rocket-Pod2","HvyCyborgLegs"],
			["HvyCyb-Bod-Rocket-Pod","HvyCyb-Wpn-Rocket-Pod","HvyCyborgLegs"],
			["CyborgChain1Ground","CyborgChaingun","CyborgLegs"],
		],
		];

		this.vtolBodies = [contingencyBodiesMediumVtol, contingencyBodiesSuperVtol, ];
		this.vtolBodies[0] = this.vtolBodies[0].concat(contingencyBodiesLightVtol);

		this.vtolBodiesLight = [contingencyBodiesLightCheap, ];
		this.vtolBodiesMedium = [contingencyBodiesMediumCheap, ];
		this.vtolBodiesHeavy = [contingencyBodiesHeavyCheap, ];
		this.vtolBodiesSuper = [contingencyBodiesSuperCheap, ];

		this.vtolWeapons = [
		[
		],
		];
		
		this.vtolWeaponsLight = [
		[
			"Missile-VTOL-MdArt",
			"Rocket-VTOL-TopAttack",
			"Rocket-VTOL-MRL",
			"Rocket-VTOL-Pod3",
			"Rocket-VTOL-Pod2",
			"Rocket-VTOL-Pod",
			"Bomb2-VTOL-HvHE",
			"Bomb1-VTOL-LtHE",
		],
		[
			"Rocket-VTOL-BB2",
			"Rocket-VTOL-BB",
		],
		[
			"Missile-VTOL-AT",
			"Rocket-VTOL-HvyA-T",
			"Rocket-VTOL-LtA-T",
		],
		];
		
		this.vtolWeaponsMedium = [
		[
			"Missile-VTOL-MdArtHvy",
			"Rocket-VTOL-TopAttackHvy",
			"Rocket-VTOL-MRLHvy",
			"Rocket-VTOL-MRL",
			"Rocket-VTOL-Pod3",
			"Rocket-VTOL-Pod2",
			"Rocket-VTOL-Pod",
			"Bomb2-VTOL-HvHE",
			"Bomb1-VTOL-LtHE",
		],
		[
			"Missile-VTOL-ATHvy",
			"Rocket-VTOL-HvyA-THvy",
			"Rocket-VTOL-LtA-THvy",
			"Rocket-VTOL-LtA-T",
		],
		];
		
		this.vtolWeaponsHeavy = [
		[
			"Missile-VTOL-MdArt",
			"Rocket-VTOL-TopAttack",
			"Rocket-VTOL-MRL",
			"Rocket-VTOL-Pod3",
			"Rocket-VTOL-Pod2",
			"Rocket-VTOL-Pod",
			"Bomb2-VTOL-HvHE",
			"Bomb1-VTOL-LtHE",
		],
		[
			"Rocket-VTOL-BB2",
			"Rocket-VTOL-BB",
		],
		[
			"Missile-VTOL-AT",
			"Rocket-VTOL-HvyA-T",
			"Rocket-VTOL-LtA-T",
		],
		];
		
		this.vtolWeaponsSuper = [
		[
			"Missile-VTOL-MdArtHvy",
			"Rocket-VTOL-TopAttackHvy",
			"Rocket-VTOL-MRLHvy",
			"Rocket-VTOL-MRL",
			"Rocket-VTOL-Pod3",
			"Rocket-VTOL-Pod2",
			"Rocket-VTOL-Pod",
			"Bomb2-VTOL-HvHE",
			"Bomb1-VTOL-LtHE",
		],
		[
			"Missile-VTOL-ATHvy",
			"Rocket-VTOL-HvyA-THvy",
			"Rocket-VTOL-LtA-THvy",
			"Rocket-VTOL-LtA-T",
		],
		];
		

		this.defenses = [
		[
			"Bunker3-Rocket-SeraphHvy",
			"Bunker2-Rocket-TopAttackHvy",
			"Bunker-Rocket-MRLHvy",
		],
		[
			"Emplacement-MdART-pit",
			"Empl2-Rocket-TopAttack",
			"Emplacement-MRL-pit",
		],
		[
			"Bunker3-Rocket-AT3Hvy",
			"Bunker2-Rocket-AT2Hvy",
			"Bunker-Rocket-ATHvy",
			"PillBox6",
			"PillBox4",
		],
		[
			"Bunker3-Rocket-Pod3Quad",
			"Bunker2-Rocket-Pod2Quad",
			"Bunker-Rocket-PodQuad",
			"Bunker-Rocket-PodTwin",
			"Bunker-Rocket-Pod",
			"PillBox1",
		],
		[
			"Super-MissileArrayPlas-Empl",
			"Super-MissileArray-Empl",
			"X-Super-Missile",
			"X-Super-Rocket",
		],
		[
			"X-Super-Missile",
			"X-Super-Rocket",
		],
		];

		this.artillery = [
		[
			"Empl3-TBM-FuelAir",
		],
		[
			"Empl3-TBM-Earthquake",
		],
		[
			"Empl3-TBM-Precision",
		],
		[
			"Bunker3-Rocket-Archangel",
			"Bunker2-Rocket-Ripple",
		],
		[
			"Emplacement-HvART-pit",
			"Emplacement-Rocket06-IDF",
		],
		];


		this.antiair = [
		[
			"P0-AASite-SAM1",
			"Empl2-Rocket-SAM",
			"Empl3-Rocket-Cherub",
			"P0-AASite-Sunburst",
		],
		[
			"Bunker3-Rocket-SAM2Hvy",
			"Bunker2-Rocket-SAMHvy",
		],
		];

		
		this.hardpoints = [
		[
			"WallTower3-Rocket-AT3Hvy",
			"WallTower2-Rocket-AT2Hvy",
			"WallTower-Rocket-ATHvy",
		],
		[
			"WallTower3-Rocket-Pod3Quad",
			"WallTower2-Rocket-Pod2Quad",
			"WallTower-Rocket-PodQuad",
			"WallTower-Rocket-PodTwin",
		],
		[
			"GuardTower-ATMiss",
			"Tower2-Rocket-AT2",
			"GuardTower5",
			"Tower-Cannon-Lgt",
		],
		[
			"Tower3-Rocket-Pod3",
			"Tower2-Rocket-Pod2",
			"GuardTower6",
			"GuardTower1",
		],
		];
		
		this.researchPathPrimary = [
			"R-Wpn-Cannon-Damage01",
			"R-Vehicle-Prop-Halftracks",
			"R-Vehicle-Body04",
			"R-Wpn-Rocket05-MiniPod",
			"R-Struc-PowerModuleMk1",
			"R-Wpn-Rocket02-MRL",
		];

		this.researchPathAT = [
			"R-Defense-Tower-Cannon-Lgt",
			"R-Defense-Tower-Rocket-Pod",
			"R-Defense-Bunker-Rocket-Pod",
			"R-Defense-Tower-Rocket-AT",
			"R-Defense-WallTower-Rocket-ATHvy",
			"R-Defense-Bunker-Rocket-ATHvy",
			"R-Defense-WallTower-Rocket-PodQuad",
			"R-Defense-Bunker-Rocket-PodQuad",
			"R-Defense-Tower2-Rocket-Pod2",
			"R-Defense-Tower2-Rocket-AT2",
			"R-Defense-WallTower2-Rocket-AT2Hvy",
			"R-Defense-Bunker2-Rocket-AT2Hvy",
			"R-Defense-WallTower2-Rocket-Pod2Quad",
			"R-Defense-Bunker2-Rocket-Pod2Quad",
			"R-Defense-Tower3-Rocket-Pod3",
			"R-Defense-Tower3-Rocket-AT3",
			"R-Defense-WallTower3-Rocket-AT3Hvy",
			"R-Defense-Bunker3-Rocket-AT3Hvy",
			"R-Defense-WallTower3-Rocket-Pod3Quad",
			"R-Defense-Bunker3-Rocket-Pod3Quad",
			"R-Defense-Super-Rocket",
			"R-Wpn-Rocket-Damage09",
			"R-Wpn-Rocket-ROF09",
			"R-Wpn-Rocket-Accuracy09",
			"R-Defense-Super-Missile",
		];
		
		this.researchPathAP = [
			"R-Defense-Tower-Rocket-Pod",
			"R-Defense-Bunker-Rocket-Pod",
			"R-Defense-Empl-Rocket-MRL",
			"R-Defense-Bunker-Rocket-MRLHvy",
			"R-Defense-WallTower-Rocket-PodQuad",
			"R-Defense-Bunker-Rocket-PodQuad",
			"R-Defense-Tower2-Rocket-Pod2",
			"R-Defense-Empl2-Rocket-TopAttack",
			"R-Defense-Bunker2-Rocket-TopAttackHvy",
			"R-Defense-WallTower2-Rocket-Pod2Quad",
			"R-Defense-Bunker2-Rocket-Pod2Quad",
			"R-Defense-Tower3-Rocket-Pod3",
			"R-Defense-Empl3-Rocket-Seraph",
			"R-Defense-Bunker3-Rocket-SeraphHvy",
			"R-Defense-WallTower3-Rocket-Pod3Quad",
			"R-Defense-Bunker3-Rocket-Pod3Quad",
			"R-Wpn-Rocket-ROF09",
			"R-Wpn-Rocket-Damage09",
			"R-Wpn-Rocket-Accuracy09",
			"R-Defense-Super-MissileArray",
		];
		
		this.researchPathAA = [
			"R-Defense-Tower-Rocket-Pod",
			"R-Defense-Bunker-Rocket-Pod",
			"R-Defense-Empl-Rocket-Sunburst",
			"R-Defense-Empl2-Rocket-SAM",
			"R-Defense-Bunker2-Rocket-SAMHvy",
			"R-Defense-Empl3-Rocket-Cherub",
			"R-Defense-Empl3-Rocket-SAM2",
			"R-Defense-Bunker3-Rocket-SAM2Hvy",
			"R-Wpn-Rocket-Damage09",
			"R-Wpn-Rocket-Accuracy09",
			"R-Wpn-Rocket-ROF09",
		];
		
		this.researchPathAB = [
			"R-Defense-Empl2-Rocket-Ripple",
			"R-Defense-Bunker2-Rocket-Ripple",
			"R-Wpn-Rocket03-HvAT",
			"R-Defense-Empl3-TBM-FuelAir",
			"R-Defense-Empl3-TBM-Precision",
			"R-Wpn-Rocket-BB2",
			"R-Defense-Empl3-Rocket-Archangel",
			"R-Defense-Bunker3-Rocket-Archangel",
			"R-Defense-Empl3-TBM-Earthquake",
			"R-Wpn-Missile-ROF03",
			"R-Wpn-Rocket-Damage09",
			"R-Wpn-Rocket-ROF09",
			"R-Wpn-Rocket-Accuracy09",
		];
		
	break;
	}
}

function rnd() {
	return random(201)-100;
}

function setTimers() {
	setTimer("updateStatus",		2000+rnd());
	setTimer("huntForOil", 			7000+rnd());
	setTimer("doResearch", 			12000+rnd());
	setTimer("executeBuildOrder",		5000+rnd());
	setTimer("attackStuff",			3000+rnd());
	setTimer("vtolAttack",			5000+rnd());
	setTimer("cheat",				30000+rnd());
	setTimer("becomeHarder",		480000+rnd());
	setTimer("adapt",				30000+rnd());
	setTimer("changeProductionRates",	90000+rnd());
	setTimer("sendAllForRepair",		1000+rnd());
	setTimer("produceDroids",		3000+rnd());
	setTimer("relaxStats",			10000+rnd());
	setTimer("balanceGroups",		10000+rnd());
	setTimer("returnDefendersToBase",	20000+rnd());
	setTimer("callUpdateEnemyInfo",	2000+rnd());
	setTimer("harassStuff",			3000+rnd());
	setTimer("buildWindFarm",		60000+rnd());
	if (REGROUP_FREQUENCY>0)
		setTimer("regroupRegularly",		REGROUP_FREQUENCY+rnd());
}

function myBuildOrder() {
	var labCount = enumStruct(me, lab).length;
	var factoryCount = enumStruct(me, factory).length;
	var commandCount = enumStruct(me, command).length;
	var genCount = enumStruct(me, generator).length;
	var derrickCount = enumStruct(me, derrick).length;
	var borgCount = enumStruct(me, borgfac).length;
	var vtolCount = enumStruct(me, vtolfac).length;
	
	var labTarget = 0;
	var factoryTarget = 0;
	var commandTarget = 0;
	var genTarget = 0;
	var derrickTarget = 0;
	var borgTarget = 0;
	var vtolTarget = 0;
	
	if (genCount < 2 && playerPower(me) < EXTREME_LOW_POWER && isStructureAvailable(generator,me))
		return buildBasicStructure(generator);
	for (var i=0; i < buildOrder.length; ++i) {
		if (typeof(buildOrder[i])!="string")
			debug("ERROR: Player ",me,"'s build list includes a structure that the AI doesn't recognize at index ",i,". The listed structure will be ignored.");
		else {
			switch (buildOrder[i]) {
			case lab:
				labTarget += 1;
				if (labCount < labTarget && isStructureAvailable(lab,me))
					return buildBasicStructure(lab);
				break;
			case factory:
				factoryTarget += 1;
				if (factoryCount < factoryTarget && isStructureAvailable(factory,me))
					return buildBasicStructure(factory);
				break;
			case command:
				commandTarget += 1;
				if (commandCount < commandTarget && isStructureAvailable(command,me))
					return buildBasicStructure(command);
				break;
			case generator:
				genTarget += 1;
				if (genCount < genTarget && isStructureAvailable(generator,me))
					return buildBasicStructure(generator);
				break;
			case derrick:
				derrickTarget += 1;
				if (derrickCount < derrickTarget && isStructureAvailable(derrick,me))
					return buildBasicStructure(derrick);
				break;
			case borgfac:
				borgTarget += 1;
				if (borgCount < borgTarget && isStructureAvailable(borgfac,me))
					return buildBasicStructure(borgfac);
				break;
			case vtolfac:
				vtolTarget += 1;
				if (vtolCount < vtolTarget && isStructureAvailable(vtolfac,me))
					return buildBasicStructure(vtolfac);
				break;
			default:
				debug("ERROR: Player ",me,"'s build list includes a structure that the AI doesn't recognize at index ",i,". The listed structure will be ignored.");
			}
		}
	/*if (factoryCount < 1 && isStructureAvailable(factory,me))
		return buildBasicStructure(factory);
	if (labCount < 1 && isStructureAvailable(lab,me))
		return buildBasicStructure(lab);
	if (labCount < 2 && isStructureAvailable(lab,me))
		return buildBasicStructure(lab,0);
	if (commandCount < 1 && isStructureAvailable(command,me))
		return buildBasicStructure(command,0);
	if (factoryCount < 2 && isStructureAvailable(factory,me))
		return buildBasicStructure(factory,0);
	if ((genCount < 2) && isStructureAvailable(generator,me))
		return buildBasicStructure(generator);
	if (labCount < 3 && isStructureAvailable(lab,me))
		return buildBasicStructure(lab,0);*/
	}
	if (borgCount < 2+(personality.subpersonality==1) && isStructureAvailable(borgfac,me))
		return buildBasicStructure(borgfac,0);
	if (vtolCount < 1 && isStructureAvailable(vtolfac,me)) 
		return buildBasicStructure(vtolfac,0);
	return false;
}
